@@ -23,7 +23,7 @@
 #ifndef MODUTILS_UTIL_H
 #define MODUTILS_UTIL_H 1
 
-#ident "$Id: util.h 1.6.1.3 Thu, 16 Nov 2000 09:29:06 +1100 kaos $"
+#ident "$Id: util.h 1.9 Thu, 07 Dec 2000 22:40:49 +1100 kaos $"
 
 #include <stdio.h>
 #include <sys/stat.h>
@@ -94,6 +94,7 @@ void gzf_close(int fd);
 
 #endif /* CONFIG_USE_ZLIB */
 
-static const char symprefix[] = "__insmod_";
+#define SYMPREFIX "__insmod_";
+extern const char symprefix[10];	/* Must be sizeof(SYMPREFIX), including nul */
 
 #endif /* util.h */
