@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_common.c 1.6 Fri, 08 Sep 2000 16:46:27 +1100 kaos $"
+#ident "$Id: obj_common.c 1.7 Sun, 17 Dec 2000 10:18:04 +1100 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -27,6 +27,7 @@
 
 #include <obj.h>
 #include <util.h>
+#include <module.h>
 
 /*======================================================================*/
 
@@ -321,3 +322,78 @@ obj_extend_section (struct obj_section *sec, unsigned long more)
   sec->contents = xrealloc(sec->contents, sec->header.sh_size += more);
   return sec->contents + oldsize;
 }
+
+/* Convert an object pointer (address) to a native pointer and vice versa.
+ * It gets interesting when the object has 64 bit pointers but modutils
+ * is running 32 bit.  This is nasty code but it stops the compiler giving
+ * spurious warning messages.  "I know what I am doing" ...
+ */
+
+void *
+obj_addr_to_native_ptr (ElfW(Addr) addr)
+{
+	unsigned int convert = (sizeof(void *) << 8) + sizeof(addr);	/* to, from */
+	union obj_ptr_4 p4;
+	union obj_ptr_8 p8;
+	switch (convert) {
+	case 0x0404:
+		p4.addr = addr;
+		return(p4.ptr);
+		break;
+	case 0x0408:
+		p4.addr = addr;
+		if (p4.addr != addr) {
+			error("obj_addr_to_native_ptr truncation %" tgt_long_fmt "x",
+				(tgt_long) addr);
+			exit(1);
+		}
+		return(p4.ptr);
+		break;
+	case 0x0804:
+		p8.addr = addr;
+		return(p8.ptr);
+		break;
+	case 0x0808:
+		p8.addr = addr;
+		return(p8.ptr);
+		break;
+	default:
+		error("obj_addr_to_native_ptr unknown conversion 0x%04x", convert);
+		exit(1);
+	}
+}
+
+ElfW(Addr)
+obj_native_ptr_to_addr (void *ptr)
+{
+	unsigned int convert = (sizeof(ElfW(Addr)) << 8) + sizeof(ptr);	/* to, from */
+	union obj_ptr_4 p4;
+	union obj_ptr_8 p8;
+	switch (convert) {
+	case 0x0404:
+		p4.ptr = ptr;
+		return(p4.addr);
+		break;
+	case 0x0408:
+		p8.ptr = ptr;
+		p4.addr = p8.addr;
+		if (p4.addr != p8.addr) {
+			error("obj_native_ptr_to_addr truncation %" tgt_long_fmt "x",
+				(tgt_long) p8.addr);
+			exit(1);
+		}
+		return(p4.addr);
+		break;
+	case 0x0804:
+		p4.ptr = ptr;
+		return(p4.addr);	/* compiler expands to 8 */
+		break;
+	case 0x0808:
+		p8.ptr = ptr;
+		return(p8.addr);
+		break;
+	default:
+		error("obj_native_ptr_to_addr unknown conversion 0x%04x", convert);
+		exit(1);
+	}
+}
