@@ -52,7 +52,7 @@ char *aliaslist[] =
 
 	"block-major-1 rd",
 	"block-major-2 floppy",
-	"block-major-3 ide-probe",
+	"block-major-3 ide-probe-mod",
 	"block-major-7 loop",
 	"block-major-8 sd_mod",
 	"block-major-9 md", /* For modular RAID */
@@ -63,7 +63,7 @@ char *aliaslist[] =
 	"block-major-17 optcd",
 	"block-major-18 sjcd",
 	"block-major-20 mcdx",
-	"block-major-22 ide-probe",
+	"block-major-22 ide-probe-mod",
 	"block-major-23 mcd",
 	"block-major-24 sonycd535",
 	"block-major-25 sbpcd",
@@ -71,10 +71,16 @@ char *aliaslist[] =
 	"block-major-27 sbpcd",
 	"block-major-29 aztcd",
 	"block-major-32 cm206",
-	"block-major-33 ide-probe",
-	"block-major-34 ide-probe",
+	"block-major-33 ide-probe-mod",
+	"block-major-34 ide-probe-mod",
 	"block-major-37 ide-tape",
 	"block-major-44 ftl",		/* from David Woodhouse <dwmw2@infradead.org> */
+	"block-major-56 ide-probe-mod",
+	"block-major-57 ide-probe-mod",
+	"block-major-88 ide-probe-mod",
+	"block-major-89 ide-probe-mod",
+	"block-major-90 ide-probe-mod",
+	"block-major-91 ide-probe-mod",
 	"block-major-93 nftl",		/* from David Woodhouse <dwmw2@infradead.org> */
 
 	"char-major-4 serial",
@@ -122,6 +128,7 @@ char *aliaslist[] =
 	"char-major-90 mtdchar",	/* from David Woodhouse <dwmw2@infradead.org> */
 	"char-major-99 ppdev",
 	"char-major-107 3dfx", /* from Tigran Aivazian <tigran@sco.COM> */
+	"char-major-161 ircomm-tty",
 
 	"dos msdos",
 	"dummy0 dummy",
@@ -136,8 +143,8 @@ char *aliaslist[] =
 	"net-pf-1 unix",	/* PF_UNIX	1  Unix domain sockets */
 	"net-pf-2 ipv4",	/* PF_INET	2  Internet IP Protocol */
 	"net-pf-3 off",		/* PF_AX25	3  Amateur Radio AX.25 */
-	"net-pf-4 off",		/* PF_IPX	4  Novell IPX */
-	"net-pf-5 off",		/* PF_APPLETALK	5  Appletalk DDP */
+	"net-pf-4 ipx",		/* PF_IPX	4  Novell IPX */
+	"net-pf-5 appletalk",	/* PF_APPLETALK	5  Appletalk DDP */
 	"net-pf-6 off",		/* PF_NETROM	6  Amateur radio NetROM */
 				/* PF_BRIDGE	7  Multiprotocol bridge */
 				/* PF_AAL5	8  Reserved for Werner's ATM */
@@ -151,6 +158,10 @@ char *aliaslist[] =
 	"netalias-2 ip_alias",
 	"plip0 plip",
 	"plip1 plip",
+	"cipcb0 cipcb",
+	"cipcb1 cipcb",
+	"cipcb2 cipcb",
+	"cipcb3 cipcb",
 	"ppp0 ppp",
 	"ppp1 ppp",
 	"scsi_hostadapter off",	/* if not in config file */
@@ -168,6 +179,8 @@ char *aliaslist[] =
         "parport_lowlevel parport_ax",
 #endif
 
+	"tty-ldisc-11 irtty",
+
 	NULL			/* marks the end of the list! */
 };
 
@@ -215,6 +228,7 @@ char *prune[] =
 	"modules.pcimap",
 	"modules.isapnpmap",
 	"modules.usbmap",
+	"modules.parportmap",
 	"System.map",
 	".config",
 	"build",		/* symlink to source tree */
